function visualizeParamSweep(nVals, hVals, aVals, peakVals, hTopAxes)
% Plot routine to accompany parameter sweep for trussCantilever model
%
% Copyright 2014-2016 The MathWorks, Inc.

A = length(aVals); % dim3 
N = length(nVals); % dim2 if not squeezed

if numel(peakVals)>400
   LS = 'none';
else
   LS = ':';
end

if A==1
	sf = surf(hTopAxes,nVals,hVals,log10(abs(peakVals)));
	title(sprintf('Log of Maximum Y Deflection \n (%3.2f cross section)',aVals),...
		'Interpreter','none','FontSize', 14, 'FontWeight', 'Bold');
	view(-37,38)
	set(gca,'ydir','reverse');
	set(gca,'xlim',[min(nVals) max(nVals)]);
	set(gca,'ylim',[min(hVals) max(hVals)]);
	set(sf,'LineStyle',LS);  
	set(sf,'FaceAlpha',1.0)
	
	xlabel('Number of horizontal Segments','FontSize',8);
	ylabel('Height of truss','FontSize',8);
else
	if N==1
		sf = surf(hTopAxes,aVals,hVals,log10(abs(squeeze(peakVals))));
		title(sprintf('Log of Maximum Y Deflection \n (%i segments)',nVals),...
			'Interpreter','none','FontSize', 14, 'FontWeight', 'Bold');
		view(-37,38)
		set(gca,'ydir','reverse');
		set(gca,'xlim',[min(aVals) max(aVals)]);
		set(gca,'ylim',[min(hVals) max(hVals)]);
		set(sf,'LineStyle',LS);  
		set(sf,'FaceAlpha',1.0)
		
		xlabel('Cross section','FontSize',8);
		ylabel('Height of truss','FontSize',8);
	else
		logPeakVals = log10(abs(peakVals));
		yMin = min(min(min(logPeakVals)));
		yMax = max(max(max(logPeakVals)));
		for nn=1:N
			subplot(N,1,nn);
			sf = surf(nVals,hVals,logPeakVals(:,:,nn));
			if nn==1
				title(sprintf('Log of Maximum Y Deflection \n(%3.2f cross section)',aVals(nn)),...
					'Interpreter','none','FontSize', 14, 'FontWeight', 'Bold');
			else
				title(sprintf('(%3.2f cross section)',aVals(nn)),...
					'Interpreter','none','FontSize', 14, 'FontWeight', 'Bold');
			end
			view(-37,38)
			set(gca,'ydir','reverse');
			set(gca,'xlim',[min(nVals) max(nVals)]);
			set(gca,'ylim',[min(hVals) max(hVals)]);
			set(gca,'zlim',[yMin yMax]);
			set(sf,'LineStyle',LS)
			set(sf,'FaceAlpha',1.0)
		end
		
		xlabel('Number of horizontal Segments','FontSize',8);
		ylabel('Height of truss','FontSize',8);
	end
end


end